==> igniteui-react-charts-18.5.1.tgz: package/esm5/lib/Stacked100AreaSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StackedAreaSeries } from "./StackedAreaSeries";
import { IStacked100Series_$type } from "./IStacked100Series";
import { markType } from "igniteui-react-core";
import { Stacked100DataPreparer } from "./Stacked100DataPreparer";
import { StackedAreaSeriesView } from "./StackedAreaSeriesView";
import { Defaults } from "./Defaults";
/**
 * @hidden
 */
var Stacked100AreaSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Stacked100AreaSeries, _super);
    function Stacked100AreaSeries() {
        var _this = _super.call(this) || this;
        _this.ab = Stacked100AreaSeries.$;
        return _this;
    }
    Stacked100AreaSeries.prototype.get_xo = function () {
        return true;
    };
    Stacked100AreaSeries.prototype.ac = function () {
        _super.prototype.ac.call(this);
        this.pq(false);
    };
    Stacked100AreaSeries.prototype.ch = function () {
        return new Stacked100AreaSeriesView(this);
    };
    Stacked100AreaSeries.prototype.o1 = function (a) {
        _super.prototype.o1.call(this, a);
        this.ym = a;
    };
    Stacked100AreaSeries.prototype.x4 = function () {
        _super.prototype.x4.call(this);
        Stacked100DataPreparer.a(this);
    };
    Object.defineProperty(Stacked100AreaSeries.prototype, "useHighMarkerFidelity", {
        get: function () {
            return this.wj;
        },
        enumerable: false,
        configurable: true
    });
    Stacked100AreaSeries.$t = markType(Stacked100AreaSeries, 'Stacked100AreaSeries', StackedAreaSeries.$, [IStacked100Series_$type]);
    return Stacked100AreaSeries;
}(StackedAreaSeries));
export { Stacked100AreaSeries };
/**
 * @hidden
 */
var Stacked100AreaSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Stacked100AreaSeriesView, _super);
    function Stacked100AreaSeriesView(a) {
        return _super.call(this, a) || this;
    }
    Stacked100AreaSeriesView.prototype.au = function () {
        _super.prototype.au.call(this);
        if (!this.q) {
            this.c3.ub = Defaults.e;
        }
    };
    Stacked100AreaSeriesView.$t = markType(Stacked100AreaSeriesView, 'Stacked100AreaSeriesView', StackedAreaSeriesView.$);
    return Stacked100AreaSeriesView;
}(StackedAreaSeriesView));
export { Stacked100AreaSeriesView };

==> igniteui-react-charts-18.6.0.tgz: package/esm5/lib/Stacked100AreaSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StackedAreaSeries } from "./StackedAreaSeries";
import { IStacked100Series_$type } from "./IStacked100Series";
import { markType } from "igniteui-react-core";
import { Stacked100DataPreparer } from "./Stacked100DataPreparer";
import { StackedAreaSeriesView } from "./StackedAreaSeriesView";
import { Defaults } from "./Defaults";
/**
 * @hidden
 */
var Stacked100AreaSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Stacked100AreaSeries, _super);
    function Stacked100AreaSeries() {
        var _this = _super.call(this) || this;
        _this.ab = Stacked100AreaSeries.$;
        return _this;
    }
    Stacked100AreaSeries.prototype.get_xp = function () {
        return true;
    };
    Stacked100AreaSeries.prototype.ac = function () {
        _super.prototype.ac.call(this);
        this.pr(false);
    };
    Stacked100AreaSeries.prototype.cd = function () {
        return new Stacked100AreaSeriesView(this);
    };
    Stacked100AreaSeries.prototype.o2 = function (a) {
        _super.prototype.o2.call(this, a);
        this.yn = a;
    };
    Stacked100AreaSeries.prototype.x5 = function () {
        _super.prototype.x5.call(this);
        Stacked100DataPreparer.a(this);
    };
    Object.defineProperty(Stacked100AreaSeries.prototype, "useHighMarkerFidelity", {
        get: function () {
            return this.wk;
        },
        enumerable: false,
        configurable: true
    });
    Stacked100AreaSeries.$t = markType(Stacked100AreaSeries, 'Stacked100AreaSeries', StackedAreaSeries.$, [IStacked100Series_$type]);
    return Stacked100AreaSeries;
}(StackedAreaSeries));
export { Stacked100AreaSeries };
/**
 * @hidden
 */
var Stacked100AreaSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Stacked100AreaSeriesView, _super);
    function Stacked100AreaSeriesView(a) {
        return _super.call(this, a) || this;
    }
    Stacked100AreaSeriesView.prototype.au = function () {
        _super.prototype.au.call(this);
        if (!this.q) {
            this.c3.uc = Defaults.e;
        }
    };
    Stacked100AreaSeriesView.$t = markType(Stacked100AreaSeriesView, 'Stacked100AreaSeriesView', StackedAreaSeriesView.$);
    return Stacked100AreaSeriesView;
}(StackedAreaSeriesView));
export { Stacked100AreaSeriesView };
